# -*- coding: utf-8 -*-
from setuptools import setup

package_dir = \
{'': 'src'}

packages = \
['nox_poetry']

package_data = \
{'': ['*']}

install_requires = \
['nox>=2020.8.22', 'packaging>=20.9', 'tomlkit>=0.7']

setup_kwargs = {
    'name': 'nox-poetry',
    'version': '1.0.1',
    'description': 'nox-poetry',
    'long_description': '# nox-poetry\n\n[![PyPI](https://img.shields.io/pypi/v/nox-poetry.svg)][pypi_]\n[![Python Version](https://img.shields.io/pypi/pyversions/nox-poetry)][python version]\n[![License](https://img.shields.io/pypi/l/nox-poetry)][license]\n\n[![Read the documentation at https://nox-poetry.readthedocs.io/](https://img.shields.io/readthedocs/nox-poetry/latest.svg?label=Read%20the%20Docs)][read the docs]\n[![Tests](https://github.com/cjolowicz/nox-poetry/workflows/Tests/badge.svg)][tests]\n[![Codecov](https://codecov.io/gh/cjolowicz/nox-poetry/branch/main/graph/badge.svg)][codecov]\n\n[pypi_]: https://pypi.org/project/nox-poetry/\n[python version]: https://pypi.org/project/nox-poetry\n[read the docs]: https://nox-poetry.readthedocs.io/\n[tests]: https://github.com/cjolowicz/nox-poetry/actions?workflow=Tests\n[codecov]: https://app.codecov.io/gh/cjolowicz/nox-poetry\n\nUse [Poetry] inside [Nox] sessions\n\nThis package provides a drop-in replacement for the `nox.session` decorator,\nand for the `nox.Session` object passed to user-defined session functions.\nThis enables `session.install` to install packages at the versions specified in the Poetry lock file.\n\n```python\nfrom nox_poetry import session\n\n@session(python=["3.10", "3.9"])\ndef tests(session):\n    session.install("pytest", ".")\n    session.run("pytest")\n```\n\n**Disclaimer:** _This project is not affiliated with Nox, and not an official Nox plugin._\n\n## Installation\n\nInstall `nox-poetry` from the Python Package Index:\n\n```console\n$ pip install nox-poetry\n```\n\n**Important:**\nThis package must be installed into the same environment that Nox is run from.\nIf you installed Nox using [pipx],\nuse the following command to install this package into the same environment:\n\n```console\n$ pipx inject nox nox-poetry\n```\n\n## Requirements\n\n- Python 3.7+\n- Poetry >= 1.0.0\n\nYou need to have a Poetry installation on your system.\n`nox-poetry` uses Poetry via its command-line interface.\n\n## Usage\n\nImport the `@session` decorator from `nox_poetry` instead of `nox`.\nThere is nothing else you need to do.\nThe `session.install` method automatically honors the Poetry lock file when installing dependencies.\nThis allows you to manage packages used in Nox sessions as development dependencies in Poetry.\n\nThis works because session functions are passed instances of `nox_poetry.Session`,\na proxy for `nox.Session` adding Poetry-related functionality.\nBehind the scenes, nox-poetry uses Poetry to export a [constraints file] and build the package.\n\nFor more fine-grained control, additional utilities are available under the `session.poetry` attribute:\n\n- `session.poetry.installroot(distribution_format=["wheel"|"sdist"])`\n- `session.poetry.build_package(distribution_format=["wheel"|"sdist"])`\n- `session.poetry.export_requirements()`\n\nNote that `distribution_format` is a [keyword-only parameter].\n\nHere is a comparison of the different installation methods:\n\n- Use `session.install(...)` to install specific development dependencies, e.g. `session.install("pytest")`.\n- Use `session.install(".")` (or `session.poetry.installroot()`) to install your own package.\n- Use `session.run_always("poetry", "install", external=True)` to install your package with _all_ development dependencies.\n\nPlease read the next section for the tradeoffs of each method.\n\n## Why?\n\nLet\'s look at an example:\n\n```python\nfrom nox_poetry import session\n\n@session(python=["3.10", "3.9"])\ndef tests(session):\n    session.install("pytest", ".")\n    session.run("pytest")\n```\n\nThis session performs the following steps:\n\n- Build a wheel from the local package.\n- Install the wheel as well as the `pytest` package.\n- Invoke `pytest` to run the test suite against the installation.\n\nConsider what would happen in this session\nif we had imported `@session` from `nox` instead of `nox_poetry`:\n\n- Package dependencies would only be constrained by the wheel metadata, not by the lock file.\n  In other words, their versions would not be _pinned_.\n- The `pytest` dependency would not be constrained at all.\n- Poetry would be installed as a build backend every time.\n\nUnpinned dependencies mean that your checks are not reproducible and deterministic,\nwhich can lead to surprises in Continuous Integration and when collaborating with others.\nYou can solve these issues by declaring `pytest` as a development dependency,\nand installing your package and its dependencies using `poetry install`:\n\n```python\n@nox.session\ndef tests(session: Session) -> None:\n    """Run the test suite."""\n    session.run_always("poetry", "install", external=True)\n    session.run("pytest")\n```\n\nUnfortunately, this approach comes with its own set of problems:\n\n- Checks run against an editable installation of your package,\n  i.e. your local copy of the code, instead of the installed wheel your users see.\n  In the best case, any mistakes will still be caught during Continuous Integration.\n  In the worst case, you publish a buggy release because you forgot to commit some changes.\n- The package is installed, as well as all of its core and development dependencies,\n  no matter which tools a session actually runs.\n  Code formatters or linters, for example, don\'t need your package installed at all.\n  Besides being wasteful, it goes against the idea of running checks in isolated environments.\n\n`nox-poetry` uses a third approach:\n\n- Installations are performed by pip, via the `session.install` method.\n- When installing your own package, Poetry is used to build a wheel, which is passed to pip.\n- When installing third-party packages, Poetry is used to export a [constraints file],\n  which is passed to pip along with the packages.\n  The constraints file ensures that package versions are pinned by the lock file,\n  without forcing an installation of every listed dependency and sub-dependency.\n\nIn summary, this approach brings the following advantages:\n\n- You can manage tools like `pytest` as development dependencies in Poetry.\n- Dependencies are pinned by Poetry\'s lock file, making checks predictable and deterministic.\n- You can run checks against an installed wheel, instead of your local copy of the code.\n- Every tool can run in an isolated environment with minimal dependencies.\n- No need to install your package with all its dependencies if all you need is some linter.\n\n## Contributing\n\nContributions are very welcome.\nTo learn more, see the [Contributor Guide].\n\n## License\n\nDistributed under the terms of the [MIT license][license],\n_nox-poetry_ is free and open source software.\n\n## Issues\n\nIf you encounter any problems,\nplease [file an issue] along with a detailed description.\n\n## Credits\n\nThis project was generated from [@cjolowicz]\'s [Hypermodern Python Cookiecutter] template.\n\n[@cjolowicz]: https://github.com/cjolowicz\n[hypermodern python cookiecutter]: https://github.com/cjolowicz/cookiecutter-hypermodern-python\n[nox]: https://nox.thea.codes/\n[poetry]: https://python-poetry.org/\n[constraints file]: https://pip.pypa.io/en/stable/user_guide/#constraints-files\n[file an issue]: https://github.com/cjolowicz/nox-poetry/issues\n[keyword-only parameter]: https://docs.python.org/3/glossary.html#keyword-only-parameter\n[nox.sessions.session.install]: https://nox.thea.codes/en/stable/config.html#nox.sessions.Session.install\n[nox.sessions.session.run]: https://nox.thea.codes/en/stable/config.html#nox.sessions.Session.run\n[pip install]: https://pip.pypa.io/en/stable/reference/pip_install/\n[pip]: https://pip.pypa.io/\n[pipx]: https://pipxproject.github.io/pipx/\n\n<!-- github-only -->\n\n[license]: https://github.com/cjolowicz/nox-poetry/blob/main/LICENSE\n[contributor guide]: https://github.com/cjolowicz/nox-poetry/blob/main/CONTRIBUTING.md\n',
    'author': 'Claudio Jolowicz',
    'author_email': 'mail@claudiojolowicz.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/cjolowicz/nox-poetry',
    'package_dir': package_dir,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.7,<4.0',
}


setup(**setup_kwargs)
